You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by mk...@apache.org on 2013/11/28 09:38:54 UTC

svn commit: r1546310 - /myfaces/core/trunk/impl/src/main/java/org/apache/myfaces/view/facelets/impl/FaceletCompositionContextImpl.java

Author: mkurz
Date: Thu Nov 28 08:38:54 2013
New Revision: 1546310

URL: http://svn.apache.org/r1546310
Log:
MYFACES-3829 added value alwaysRecompile to doc for param org.apache.myfaces.CACHE_EL_EXPRESSIONS

Modified:
    myfaces/core/trunk/impl/src/main/java/org/apache/myfaces/view/facelets/impl/FaceletCompositionContextImpl.java

Modified: myfaces/core/trunk/impl/src/main/java/org/apache/myfaces/view/facelets/impl/FaceletCompositionContextImpl.java
URL: http://svn.apache.org/viewvc/myfaces/core/trunk/impl/src/main/java/org/apache/myfaces/view/facelets/impl/FaceletCompositionContextImpl.java?rev=1546310&r1=1546309&r2=1546310&view=diff
==============================================================================
--- myfaces/core/trunk/impl/src/main/java/org/apache/myfaces/view/facelets/impl/FaceletCompositionContextImpl.java (original)
+++ myfaces/core/trunk/impl/src/main/java/org/apache/myfaces/view/facelets/impl/FaceletCompositionContextImpl.java Thu Nov 28 08:38:54 2013
@@ -55,8 +55,10 @@ public class FaceletCompositionContextIm
      * Default is noCache. There there are four modes:
      * 
      * <ul>
      * <li>always: Only does not cache when expressions are inside user tags or the e
      * xpression contains a variable resolved using VariableMapper</li>
      * <li>allowCset: Like always, but does not allow cache when ui:param
      * was used on the current template context</li>
      * <li>strict: Like allowCset, but does not allow cache when c:set with
@@ -65,7 +67,8 @@ public class FaceletCompositionContextIm
      * </ul>
      * 
      */
-    @JSFWebConfigParam(since="2.0.8", defaultValue="noCache", expectedValues="noCache, strict, allowCset, always",
+    @JSFWebConfigParam(since="2.0.8", defaultValue="noCache",
+                       expectedValues="noCache, strict, allowCset, always, alwaysRecompile",
                        group="EL", tags="performance")
     public static final String INIT_PARAM_CACHE_EL_EXPRESSIONS = "org.apache.myfaces.CACHE_EL_EXPRESSIONS";
@@ -55,8 +55,10 @@ public class FaceletCompositionContextIm
      * 
      * <ul>
-     * <li>always: Only does not cache when expressions are inside user tags or the e
-     * xpression contains a variable resolved using VariableMapper</li>
+     * <li>alwaysRecompile (since 2.1.12): Only does not cache when the expression contains
+     * a variable resolved using VariableMapper</li>
+     * <li>always: Only does not cache when expressions are inside user tags or the
+     * expression contains a variable resolved using VariableMapper</li>
      * <li>allowCset: Like always, but does not allow cache when ui:param
      * was used on the current template context</li>